==> 1.0.1%2B1.tar.gz: android/src/main/java/com/bradyid/brady_flutter_plugin/BradySdkApi.java <==
package com.bradyid.brady_flutter_plugin;

import android.content.Context;

import com.bradysdk.api.printerconnection.CutOption;
import com.bradysdk.api.printerconnection.PrinterDetails;
import com.bradysdk.api.printerconnection.PrinterProperties;
import com.bradysdk.api.printerconnection.PrinterUpdateListener;
import com.bradysdk.api.printerconnection.PrintingOptions;
import com.bradysdk.api.printerconnection.PrintingStatus;
import com.bradysdk.api.printerdiscovery.DiscoveredPrinterInformation;
import com.bradysdk.api.printerdiscovery.PrinterDiscovery;
import com.bradysdk.api.printerdiscovery.PrinterDiscoveryListener;
import com.bradysdk.api.templates.Template;
import com.bradysdk.api.templates.TemplateObjectData;
import com.bradysdk.printengine.common.ExecutorServiceInstance;
import com.bradysdk.printengine.printinginterface.PrinterDiscoveryFactory;
import com.bradysdk.printengine.templateinterface.TemplateFactory;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;

public class BradySdkApi implements PrinterDiscoveryListener, PrinterUpdateListener {

    private Context context;
    private PrinterDiscovery printerDiscovery;
    private PrinterDetails printerDetails = null;
    private List<PrinterDiscoveryListener> listeners = new ArrayList<>();
    private List<DiscoveredPrinterInformation> foundPrinters = new ArrayList<>();
    private Template currentTemplate;
    public BradySdkApi(Context context) {
        this.context = context;
        listeners.add(this);
    }

    public void startPrinterDiscovery() {
        printerDiscovery = PrinterDiscoveryFactory.getPrinterDiscovery(context, listeners);
        printerDiscovery.startBlePrinterDiscovery();
    }

    public void stopPrinterDiscovery() {
        printerDiscovery.stopPrinterDiscovery();
    }

    public String getPrinters() {
        String printerNames = "";
        for(DiscoveredPrinterInformation printer : foundPrinters) {
            printerNames += printer.getName() + ", ";
        }
        return printerNames;
    }

    public Boolean connectToPrinter(String printer) {
        DiscoveredPrinterInformation printerObject = null;
        for (DiscoveredPrinterInformation dpi : foundPrinters) {
            if (Objects.equals(dpi.getName(), printer)) {
                printerObject = dpi;
                break;
            }
        }

        List<PrinterUpdateListener> listeners = new ArrayList<>();
        listeners.add(this);

        if (printerObject != null) {
            DiscoveredPrinterInformation finalPrinterObject = printerObject;
            Future<PrinterDetails> detailsFuture = ExecutorServiceInstance.instance().submit(() ->
                    printerDiscovery.connectToDiscoveredPrinter(this.context, finalPrinterObject, listeners));
            while (!detailsFuture.isDone()) {}
            try {
                this.printerDetails = detailsFuture.get();
            } catch (ExecutionException | InterruptedException e) {
                throw new RuntimeException(e);
            }

            if (this.printerDetails != null) {
                return true;
            }
            return false;
        }
        return false;
    }

    public String getPrinterDetails() {
        String details = "";
        if (this.printerDetails != null) {
            details += "Connection Status: " + this.printerDetails.getPrinterStatus().name();
            details += " (" + this.printerDetails.getConnectionType().name() + ")\n";
            details += "Printer Name: " + this.printerDetails.getPrinterName();
            details += " (" + this.printerDetails.getPrinterModel() + ")\n";
            details += "Supply Name: " + this.printerDetails.getSupplyName() + "\n";
            details += "Supply Dimensions: " + this.printerDetails.getSupplyDimensions() + "\n";
            Integer remainingSupply = this.printerDetails.getSupplyRemainingPercentage();
            details += "Remaining Supply: " + remainingSupply + "\n";
            Integer batteryPercentage = this.printerDetails.getBatteryLevelPercentage();
            details += "Battery Level: " + batteryPercentage;
            details += ", Charging: " + this.printerDetails.getIsAcConnected();
            return details;
        }
        return "";
    }

    public String getLastConnectedPrinterName() {
        DiscoveredPrinterInformation printerObject = this.printerDiscovery.getLastConnectedPrinter();
        if (printerObject != null) {
            return printerObject.getName();
        }
        return null;
    }

    public void setTemplate(InputStream inputStream) {
        this.currentTemplate = TemplateFactory.getTemplate(inputStream, this.context);
    }

    public void setPlaceholderValue(String placeholder, String value) {
        if (this.currentTemplate != null) {
            for (TemplateObjectData obj : this.currentTemplate.getTemplateData()) {
                if (Objects.equals(obj.getName(), placeholder)) {
                    obj.setValue(value);
                }
            }
        }
        else {
            System.out.println("Template is null (use setTemplate(InputStream) first!");
        }
    }

    public Boolean print() {
        if (this.currentTemplate != null) {
            PrintingOptions printingOptions = new PrintingOptions();
            printingOptions.setCutOption(CutOption.EndOfLabel);
            printingOptions.setNumberOfCopies(1);
            if (this.printerDetails != null) {
                Future<PrintingStatus> printFuture = ExecutorServiceInstance.instance().submit(() ->
                        printerDetails.print(this.context, this.currentTemplate, printingOptions, true));
                while (!printFuture.isDone()) {}
                try {
                    PrintingStatus printingStatus = printFuture.get();
                    if (printingStatus.name().equals("PrintingSucceeded")) {
                        return true;
                    }
                    return false;
                } catch (ExecutionException | InterruptedException e) {
                    throw new RuntimeException(e);
                }
            }
            System.out.println("Printing failed because there is no connection to the desired printer!");
            return false;
        }
        System.out.println("Template is null (use setTemplate(InputStream) first!");
        return false;
    }

    public Boolean feed() {
        if (this.printerDetails != null) {
            Future<?> feedFuture = ExecutorServiceInstance.instance().submit(() ->
                    printerDetails.feed());
            while (!feedFuture.isDone()) {}
            return true;
        }
        System.out.println("Feed failed because there is no connection to the desired printer!");
        return false;
    }

    public Boolean cut() {
        if (this.printerDetails != null) {
            Future<?> cutFuture = ExecutorServiceInstance.instance().submit(() ->
                    printerDetails.cutLabel());
            while (!cutFuture.isDone()) {}
            return true;
        }
        System.out.println("Cut failed because there is no connection to the desired printer!");
        return false;
    }

    public Boolean disconnect() {
        if (this.printerDetails != null) {
            Future<?> disconnectFuture = ExecutorServiceInstance.instance().submit(() ->
                    printerDetails.disconnect());
            while (!disconnectFuture.isDone()) {}
            this.printerDetails = null;
            return true;
        }
        System.out.println("Disconnect failed because there is no connection to the desired printer!");
        return false;
    }

    @Override
    public void printerDiscovered(DiscoveredPrinterInformation discoveredPrinterInformation) {
        if(printerDoesNotExist(discoveredPrinterInformation.getName())) {
            foundPrinters.add(discoveredPrinterInformation);
            System.out.println("Printer Found: " + discoveredPrinterInformation.getName());
        }
    }

    @Override
    public void printerDiscoveryStarted() {
        System.out.println("Printer Discovery was started...");
    }

    @Override
    public void printerDiscoveryStopped() {
        System.out.println("Printer Discovery was stopped...");
    }

    @Override
    public void PrinterUpdate(List<PrinterProperties> list) {

    }

    private boolean printerDoesNotExist(String listName) {
        boolean wasFound = false;
        for(DiscoveredPrinterInformation printer : foundPrinters){
            if (printer.getName().equals(listName)) {
                wasFound = true;
                break;
            }
        }
        return !wasFound;
    }
}

==> 1.0.3%2B1.tar.gz: android/src/main/java/com/bradyid/brady_flutter_plugin/BradySdkApi.java <==
package com.bradyid.brady_flutter_plugin;

import android.content.Context;

import com.bradysdk.api.printerconnection.CutOption;
import com.bradysdk.api.printerconnection.PrinterDetails;
import com.bradysdk.api.printerconnection.PrinterProperties;
import com.bradysdk.api.printerconnection.PrinterUpdateListener;
import com.bradysdk.api.printerconnection.PrintingOptions;
import com.bradysdk.api.printerconnection.PrintingStatus;
import com.bradysdk.api.printerdiscovery.DiscoveredPrinterInformation;
import com.bradysdk.api.printerdiscovery.PrinterDiscovery;
import com.bradysdk.api.printerdiscovery.PrinterDiscoveryListener;
import com.bradysdk.api.templates.Template;
import com.bradysdk.api.templates.TemplateObjectData;
import com.bradysdk.printengine.common.ExecutorServiceInstance;
import com.bradysdk.printengine.printinginterface.PrinterDiscoveryFactory;
import com.bradysdk.printengine.templateinterface.TemplateFactory;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Base64;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;

public class BradySdkApi implements PrinterDiscoveryListener, PrinterUpdateListener {

    private Context context;
    private PrinterDiscovery printerDiscovery;
    private PrinterDetails printerDetails = null;
    private List<PrinterDiscoveryListener> listeners = new ArrayList<>();
    private List<DiscoveredPrinterInformation> foundPrinters = new ArrayList<>();
    private Template currentTemplate;
    public BradySdkApi(Context context) {
        this.context = context;
        listeners.add(this);
    }

    public void startPrinterDiscovery() {
        printerDiscovery = PrinterDiscoveryFactory.getPrinterDiscovery(context, listeners);
        printerDiscovery.startBlePrinterDiscovery();
        printerDiscovery.startWifiPrinterDiscovery();
    }

    public String getPrinters() {
        String printerNames = "";
        for(DiscoveredPrinterInformation printer : foundPrinters) {
            printerNames += printer.getName() + ", ";
        }
        return printerNames;
    }

    public Boolean connectToPrinter(String printer) {
        DiscoveredPrinterInformation printerObject = null;
        for (DiscoveredPrinterInformation dpi : foundPrinters) {
            if (Objects.equals(dpi.getName(), printer)) {
                printerObject = dpi;
                break;
            }
        }

        List<PrinterUpdateListener> listeners = new ArrayList<>();
        listeners.add(this);

        if (printerObject != null) {
            DiscoveredPrinterInformation finalPrinterObject = printerObject;
            Future<PrinterDetails> detailsFuture = ExecutorServiceInstance.instance().submit(() ->
                    printerDiscovery.connectToDiscoveredPrinter(this.context, finalPrinterObject, listeners));
            while (!detailsFuture.isDone()) {}
            try {
                this.printerDetails = detailsFuture.get();
            } catch (ExecutionException | InterruptedException e) {
                throw new RuntimeException(e);
            }

            if (this.printerDetails != null) {
                printerDiscovery.stopPrinterDiscovery();
                return true;
            }
            return false;
        }
        return false;
    }

    public String getPrinterDetails() {
        String details = "";
        if (this.printerDetails != null) {
            details += "Connection Status: " + this.printerDetails.getPrinterStatus().name();
            details += " (" + this.printerDetails.getConnectionType().name() + ")\n";
            details += "Printer Name: " + this.printerDetails.getPrinterName();
            details += " (" + this.printerDetails.getPrinterModel() + ")\n";
            details += "Supply Name: " + this.printerDetails.getSupplyName() + "\n";
            details += "Supply Dimensions: " + this.printerDetails.getSupplyDimensions() + "\n";
            Integer remainingSupply = this.printerDetails.getSupplyRemainingPercentage();
            details += "Remaining Supply: " + remainingSupply + "\n";
            Integer batteryPercentage = this.printerDetails.getBatteryLevelPercentage();
            details += "Battery Level: " + batteryPercentage;
            details += ", Charging: " + this.printerDetails.getIsAcConnected();
            return details;
        }
        return "";
    }

    public String getLastConnectedPrinterName() {
        DiscoveredPrinterInformation printerObject = this.printerDiscovery.getLastConnectedPrinter();
        if (printerObject != null) {
            return printerObject.getName();
        }
        return null;
    }

    public void setTemplate(String base64) {
        byte[] encoded;
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.O) {
            encoded = Base64.getDecoder().decode(base64);
        }
        else {
            encoded = org.apache.commons.codec.binary.Base64.decodeBase64(base64);
        }
        InputStream inputStream = new ByteArrayInputStream(encoded);
        this.currentTemplate = TemplateFactory.getTemplate(inputStream, this.context);
    }

    public void setPlaceholderValue(String placeholder, String value) {
        if (this.currentTemplate != null) {
            for (TemplateObjectData obj : this.currentTemplate.getTemplateData()) {
                if (Objects.equals(obj.getName(), placeholder)) {
                    obj.setValue(value);
                }
            }
        }
        else {
            System.out.println("Template is null (use setTemplate(InputStream) first!");
        }
    }

    public Boolean print() {
        if (this.currentTemplate != null) {
            PrintingOptions printingOptions = new PrintingOptions();
            printingOptions.setCutOption(CutOption.EndOfLabel);
            printingOptions.setNumberOfCopies(1);
            if (this.printerDetails != null) {
                Future<PrintingStatus> printFuture = ExecutorServiceInstance.instance().submit(() ->
                        printerDetails.print(this.context, this.currentTemplate, printingOptions, true));
                while (!printFuture.isDone()) {}
                try {
                    PrintingStatus printingStatus = printFuture.get();
                    if (printingStatus.name().equals("PrintingSucceeded")) {
                        return true;
                    }
                    return false;
                } catch (ExecutionException | InterruptedException e) {
                    throw new RuntimeException(e);
                }
            }
            System.out.println("Printing failed because there is no connection to the desired printer!");
            return false;
        }
        System.out.println("Template is null (use setTemplate(InputStream) first!");
        return false;
    }

    public Boolean feed() {
        if (this.printerDetails != null) {
            Future<?> feedFuture = ExecutorServiceInstance.instance().submit(() ->
                    printerDetails.feed());
            while (!feedFuture.isDone()) {}
            return true;
        }
        System.out.println("Feed failed because there is no connection to the desired printer!");
        return false;
    }

    public Boolean cut() {
        if (this.printerDetails != null) {
            Future<?> cutFuture = ExecutorServiceInstance.instance().submit(() ->
                    printerDetails.cutLabel());
            while (!cutFuture.isDone()) {}
            return true;
        }
        System.out.println("Cut failed because there is no connection to the desired printer!");
        return false;
    }

    public Boolean disconnect() {
        if (this.printerDetails != null) {
            Future<?> disconnectFuture = ExecutorServiceInstance.instance().submit(() ->
                    printerDetails.disconnect());
            while (!disconnectFuture.isDone()) {}
            this.printerDetails = null;
            return true;
        }
        System.out.println("Disconnect failed because there is no connection to the desired printer!");
        return false;
    }

    @Override
    public void printerDiscovered(DiscoveredPrinterInformation discoveredPrinterInformation) {
        if(printerDoesNotExist(discoveredPrinterInformation.getName())) {
            foundPrinters.add(discoveredPrinterInformation);
            System.out.println("Printer Found: " + discoveredPrinterInformation.getName());
        }
    }

    @Override
    public void printerDiscoveryStarted() {
        System.out.println("Printer Discovery was started...");
    }

    @Override
    public void printerDiscoveryStopped() {
        System.out.println("Printer Discovery was stopped...");
    }

    @Override
    public void PrinterUpdate(List<PrinterProperties> list) {

    }

    private boolean printerDoesNotExist(String listName) {
        boolean wasFound = false;
        for(DiscoveredPrinterInformation printer : foundPrinters){
            if (printer.getName().equals(listName)) {
                wasFound = true;
                break;
            }
        }
        return !wasFound;
    }
}
